@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::API::Module;
 BEGIN {
-  $MetaCPAN::API::Module::VERSION = '0.01_03';
+  $MetaCPAN::API::Module::VERSION = '0.02';
 }
 # ABSTRACT: Module and dist information for MetaCPAN::API
 
@@ -48,7 +48,8 @@ sub search_module {
 
 1;
 
-__END__
+
+
 =pod
 
 =head1 NAME
@@ -57,7 +58,40 @@ MetaCPAN::API::Module - Module and dist information for MetaCPAN::API
 
 =head1 VERSION
 
-version 0.01_03
+version 0.02
+
+=head1 DESCRIPTION
+
+This role provides MetaCPAN::API with several methods to get the module and
+dist information.
+
+=head1 ATTRIBUTES
+
+=head2 module_prefix
+
+This attribute helps set the path to the module and dist requests in the REST
+API. You will most likely never have to touch this as long as you have an
+updated version of MetaCPAN::API.
+
+Default: I<module>.
+
+This attribute is read-only (immutable), meaning that once it's set on
+initialize (via C<new()>), you cannot change it. If you need to, create a
+new instance of MetaCPAN::API. Why is it immutable? Because it's better.
+
+=head1 METHODS
+
+=head2 search_dist
+
+    my @dists = $mcpan->search_dist('Moose');
+
+Searches MetaCPAN for a dist.
+
+=head2 search_module
+
+    my @modules = $mcpan->search_module('Moose');
+
+Searches MetaCPAN for a module.
 
 =head1 AUTHOR
 
@@ -72,3 +106,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
